import os
import subprocess
import sys

def install(package):
    subprocess.check_call([sys.executable, "-m", "pip", "install", package])

# Überprüfe und installiere Wand
try:
    from wand.image import Image
except ImportError:
    print("Wand wird installiert...")
    install("Wand")
    from wand.image import Image

# Überprüfe tkinter (wird normalerweise mit Python geliefert)
try:
    import tkinter as tk
    from tkinter import filedialog, messagebox
except ImportError:
    print("tkinter ist nicht installiert. Bitte installieren Sie es manuell entsprechend Ihrem Betriebssystem.")
    sys.exit(1)

class ImageConverter:
    def __init__(self, master):
        self.master = master
        master.title("Image to WebP Converter")

        self.label = tk.Label(master, text="Bildordner auswählen:")
        self.label.pack()

        self.source_entry = tk.Entry(master, width=50)
        self.source_entry.pack()

        self.browse_source_button = tk.Button(master, text="Durchsuchen", command=self.browse_source)
        self.browse_source_button.pack()

        self.label = tk.Label(master, text="Zielordner auswählen:")
        self.label.pack()

        self.destination_entry = tk.Entry(master, width=50)
        self.destination_entry.pack()

        self.browse_destination_button = tk.Button(master, text="Durchsuchen", command=self.browse_destination)
        self.browse_destination_button.pack()

        self.convert_button = tk.Button(master, text="Konvertieren", command=self.convert_images)
        self.convert_button.pack()

    def browse_source(self):
        source_directory = filedialog.askdirectory()
        if source_directory:
            self.source_entry.delete(0, 'end')
            self.source_entry.insert(0, source_directory)

    def browse_destination(self):
        destination_directory = filedialog.askdirectory()
        if destination_directory:
            self.destination_entry.delete(0, 'end')
            self.destination_entry.insert(0, destination_directory)

    def convert_images(self):
        source_directory = self.source_entry.get()
        destination_directory = self.destination_entry.get()

        if not source_directory or not destination_directory:
            messagebox.showerror("Fehler", "Bitte wählen Sie sowohl den Quell- als auch den Zielordner aus.")
            return

        for filename in os.listdir(source_directory):
            if filename.lower().endswith(('.png', '.jpg', '.jpeg', '.gif', '.tiff', '.bmp')):
                source_path = os.path.join(source_directory, filename)
                destination_path = os.path.join(destination_directory, os.path.splitext(filename)[0] + '.webp')

                with Image(filename=source_path) as img:
                    img.format = 'webp'
                    img.save(filename=destination_path)

        messagebox.showinfo("Erfolg", "Bilder erfolgreich konvertiert.")

if __name__ == "__main__":
    root = tk.Tk()
    converter = ImageConverter(root)
    root.mainloop()
